@@ -58,7 +58,7 @@
 #endif
 
 char * getVersion(){
-    return  "kissreads module 1.2.2 - Copyright INRIA - CeCILL License";
+    return  "kissreads module 1.2.5 - Copyright INRIA - CeCILL License";
 }
 //#define VERBOSE
 
@@ -97,9 +97,6 @@ void print_usage_and_exit(char * name){
 	fprintf (stderr, "\t -I the input file (toCheck.fasta) is an Intl output (incompatible with -n option) \n");
 #endif // not INPUT_FROM_KISSPLICE
     fprintf (stderr, "\t -i index_stride (int value). This is a heuristic for limiting the memory footprint. Instead of indexing each kmer of the sequences contained into the toCheck.fasta, kissreads indexes kmers occurring each \"index_stride\" position. Default = 1 (no heuristic)\n");
-	//fprintf (stderr, "\t -c Write the coverage of each position of the sequences. The fasta file will have 3 lines (instead of one) starting with \'>\' before the sequences themselves\n");
-    //	fprintf (stderr, "\t -q kmer_size for kissplice: computes qualities for variants obtained with the given kmer_size; use this if you need the quality of a SNP position, or the average quality of an indel or a splicing event\n");
-    //	fprintf (stderr, "\t -p number of sets in which to partition the set of variants \n");
     fprintf (stderr, "\t -t max number of threads (also limited by number of input files)\n");
 	fprintf (stderr, "\t -m align_file, write a file of reads mapped to sequences in file align_file\n");
 	fprintf (stderr, "\t -s silent mode\n");
@@ -144,8 +141,6 @@ int main(int argc, char **argv) {
 	size_seeds=25;
     
 	int i, k;
-    //	kmer_size=0;
-    //	nb_event_sets=1;
 	int nb_events_per_set;
     int max_substitutions=1;
     int max_threads = 1;
@@ -168,7 +163,6 @@ int main(int argc, char **argv) {
     nbits_nbseeds = 8*sizeof(uint64_t)- NBITS_OFFSET_SEED ;
     mask_nbseed  = ( 1ULL <<  (uint64_t) nbits_nbseeds  ) -1 ;
     mask_offset_seed = (1ULL << (NBITS_OFFSET_SEED)) -1 ;
-    // printf("mask nb seed %llx  %llx \n",mask_nbseed,mask_offset_seed);
     
 	// GET ALL THE READ FILES
 	// find the number of read sets
@@ -297,15 +291,6 @@ int main(int argc, char **argv) {
                 fprintf(sam_out,"SNP_header\tmapped_read\tid_read_file\tposition_where_read_is_mapped\n");
                 printf(" Will output reads mapped results in file: %s\n", optarg);
                 break;
-                //            case 'q':
-                //                printf(" Computes qualities for variants obtained with the given kmer_size, as used by kisSplice\n");
-                //                kmer_size=atoi(optarg);
-                //                quality=1;
-                //                break;
-                //            case 'p':
-                //                nb_event_sets=atoi(optarg);
-                //                printf(" Partitions the set of fasta sequences whose read coherence is to be checked in %d sets\n", nb_event_sets);
-                //                break;
                 
             case '-':
                 if(strcmp("version", optarg)==0){
@@ -315,7 +300,6 @@ int main(int argc, char **argv) {
                 printf(" what next ? %s\n",optarg);
                 break;
             default:
-                //			printf ("Unknown option %c\n", temoin);
                 print_usage_and_exit(argv[0]);
 		}
 	}
@@ -330,14 +314,7 @@ int main(int argc, char **argv) {
         fprintf(stderr, "cannot use both options -n and -I\n");
         exit(1);
     }
-    if(!map_snps && !map_invs){
-        fprintf(stderr, "sorry, kissreads is not ready yet to deal with generic input (neither kissnp, kissreads, nor intl)\n");
-        fprintf(stderr, " -- compile with option INPUT_FROM_KISSPLICE (make MYCFLAGS=-DINPUT_FROM_KISSPLICE)\n");
-        fprintf(stderr, "   or\n");
-        fprintf(stderr, " -- use either option -n or -I\n bye\n");
-        exit(1);
-    }
-#endif 
+#endif
     
     
     if(!silent){
@@ -347,13 +324,18 @@ int main(int argc, char **argv) {
         printf("Each position should be covered by at least %d reads.\n", min_coverage);
 #endif
     }
+    
+    if(size_seeds>32){
+        fprintf(stderr,"Sorry kissreads does not accept k>32, exit\n");
+        exit(1);
+    }
+    
 	init_static_variables(size_seeds);
-    //	float sum_average_read_length=0;
 	
 	gzFile * reads_files = (gzFile*) malloc(sizeof(gzFile)*number_of_read_sets);
 	p_fragment_info * results_against_set;
     
-	char *found;
+	char found;
 	// test if all formats are in fastq
 	quality=1;
 	for (i=0;i<number_of_read_sets;i++){
@@ -385,34 +367,14 @@ int main(int argc, char **argv) {
     char * line =  (char *)malloc(sizeof(char)*1048576); // 1048576
 	number_of_starters = number_of_sequences_in_file(file,line);
     free(line);
-    //
-    //    if(map_snps)
-    //        nb_events_per_set = (number_of_starters/2)/nb_event_sets;
-    //    else if(map_invs)
-    //        nb_events_per_set = (number_of_starters/4)/nb_event_sets;
-    //    else
-    //        nb_events_per_set = number_of_starters/nb_event_sets; // TODO FINISH GENERIC
     
     nb_events_per_set = (number_of_starters/number_paths_per_event);
     
     
     if(!silent){
-        //        if(map_snps) printf("\nThe number of sequences in %s file is %d, therefore the number of mouths is %d\n", toCheck_file, number_of_starters, nb_events_per_set);
-        //        else if(map_invs) printf("\nThe number of sequences in %s file is %d, therefore the number of inversions is %d\n", toCheck_file, number_of_starters, nb_events_per_set);
-        //        else printf("\nThe number of sequences in %s file is %d (%d events)\n", toCheck_file, number_of_starters, nb_events_per_set);
         printf("\nThe number of sequences in %s file is %d (%d events)\n", toCheck_file, number_of_starters, nb_events_per_set);
     }
     
-    
-    
-    //	for ( j = 1; j<=nb_event_sets; j++ )
-    //    {
-    //	    if ( j == nb_event_sets ){ // FIXME: ?
-    //            if(map_snps) nb_events_per_set = (number_of_starters/2) - nb_events_per_set * (nb_event_sets-1);
-    //            else if(map_invs) nb_events_per_set = (number_of_starters/4) - nb_events_per_set * (nb_event_sets-1);
-    //            else nb_events_per_set = (number_of_starters) - nb_events_per_set * (nb_event_sets-1);
-    //        }
-    
     if(!silent)	printf("\nIndexing\n");
     results_against_set = index_starters_from_input_file (size_seeds, nb_events_per_set, number_paths_per_event, input_only_upper, index_stride);
     
@@ -444,7 +406,7 @@ int main(int argc, char **argv) {
         print_results_2_paths_per_event(coherent_out, uncoherent_out, results_against_set, number_of_read_sets, nb_events_per_set, quality);
     else if(map_invs)
         print_results_invs(coherent_out, uncoherent_out, results_against_set, number_of_read_sets, nb_events_per_set, quality);
-    //    else   print_generic_results(coherent_out, uncoherent_out, results_against_set, number_of_read_sets, nb_events_per_set, quality); // TODO
+    else   print_generic_results(coherent_out, uncoherent_out, results_against_set, number_of_read_sets, nb_events_per_set, quality); // TODO
     
     free(seed_table);
     FreeHashTable((struct HashTable*)seeds_count);
@@ -462,10 +424,7 @@ int main(int argc, char **argv) {
         free(results_against_set[i]);
     }
     free(results_against_set);
-    //} // nb event set
-    
-    
-	//average_size_reads=sum_average_read_length/number_of_read_sets;
+
     
 	gzclose(file);
 	fclose(coherent_out);
